@@ -166,8 +166,6 @@ class CanonicalExpressionPickler(BasePickler):
         ''.join(elem for elem in sorted(canonelems)),
         self.TUPLE_CLOSE.encode('utf-8')])
 
-    # FIXME: implement meta-values
-
     # Tuples(/maps/dictionaries):
     elif isinstance(expression, TupleCompatible):
       special_pattern = lambda expr:(
@@ -176,7 +174,8 @@ class CanonicalExpressionPickler(BasePickler):
       if special_pattern(expression):
         if expression[0] == self.QUOTE_PROCEDURE:
           if (isinstance(expression[1], TupleCompatible) and
-              all(special_pattern(expression[1][key]) and
+              all(isinstance(expression[1][key], TupleCompatible) and
+                  special_pattern(expression[1][key])             and
                   expression[1][key][0] == self.UNQUOTE_PROCEDURE
                   for key in expression[1])):
             return ''.join([
